<?php

namespace Bixo\Onboarding\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Bixo\Onboarding\Http\Requests\OnboardingRequest;
use Bixo\Onboarding\Models\Onboarding;

/**
 * Admin web controller class.
 */
class OnboardingWorkflowController extends BaseController
{

    /**
     * Workflow controller function for onboarding.
     *
     * @param Model   $onboarding
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(OnboardingRequest $request, Onboarding $onboarding, $step)
    {

        try {

            $onboarding->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('onboarding::onboarding.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/onboarding/onboarding/' . $onboarding->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/onboarding/onboarding/' . $onboarding->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for onboarding.
     *
     * @param Model   $onboarding
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Onboarding $onboarding, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $onboarding->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('onboarding::onboarding.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('onboarding::admin.onboarding.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('onboarding::admin.onboarding.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('onboarding::admin.onboarding.message', $data)->render();

        }

    }
}
