<?php

namespace Bixo\Onboarding\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Onboarding\Models\Onboarding;

class OnboardingPolicy
{

    /**
     * Determine if the given user can view the onboarding.
     *
     * @param UserPolicy $user
     * @param Onboarding $onboarding
     *
     * @return bool
     */
    public function view(UserPolicy $user, Onboarding $onboarding)
    {
        if ($user->canDo('onboarding.onboarding.view') && $user->isAdmin()) {
            return true;
        }

        return $onboarding->user_id == user_id() && $onboarding->user_type == user_type();
    }

    /**
     * Determine if the given user can create a onboarding.
     *
     * @param UserPolicy $user
     * @param Onboarding $onboarding
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('onboarding.onboarding.create');
    }

    /**
     * Determine if the given user can update the given onboarding.
     *
     * @param UserPolicy $user
     * @param Onboarding $onboarding
     *
     * @return bool
     */
    public function update(UserPolicy $user, Onboarding $onboarding)
    {
        if ($user->canDo('onboarding.onboarding.edit') && $user->isAdmin()) {
            return true;
        }

        return $onboarding->user_id == user_id() && $onboarding->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given onboarding.
     *
     * @param UserPolicy $user
     * @param Onboarding $onboarding
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Onboarding $onboarding)
    {
        return $onboarding->user_id == user_id() && $onboarding->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given onboarding.
     *
     * @param UserPolicy $user
     * @param Onboarding $onboarding
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Onboarding $onboarding)
    {
        if ($user->canDo('onboarding.onboarding.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given onboarding.
     *
     * @param UserPolicy $user
     * @param Onboarding $onboarding
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Onboarding $onboarding)
    {
        if ($user->canDo('onboarding.onboarding.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
