<?php

namespace Bixo\Onboarding\Providers;

use Illuminate\Support\ServiceProvider;

class OnboardingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'onboarding');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'onboarding');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerOnboarding();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerOnboarding()
    {
        $this->app->bind('onboarding', function($app) {
            return new Onboarding($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Onboarding', 'Lavalite\Onboarding\Facades\Onboarding');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.onboarding', function ($app) {
            return $this->app->make('Bixo\Onboarding\Onboarding');
        });

                // Bind Onboarding to repository
        $this->app->bind(
            'Bixo\Onboarding\Interfaces\OnboardingRepositoryInterface',
            \Bixo\Onboarding\Repositories\Eloquent\OnboardingRepository::class
        );

        $this->app->register(\Bixo\Onboarding\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Bixo\Onboarding\Providers\RouteServiceProvider::class);
                // $this->app->register(\Bixo\Onboarding\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and onboarding's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.onboarding'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeOnboarding::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.onboarding'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/onboarding.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/onboarding')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/onboarding')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
