<?php

namespace Bixo\Onboarding\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Bixo\Onboarding\Models\Onboarding;

class OnboardingAction
{
    /**
     * Perform the complete action.
     *
     * @param Onboarding $onboarding
     *
     * @return Onboarding
     */
    public function complete(Onboarding $onboarding)
    {
        try {
            $onboarding->status = 'complete';
            return $onboarding->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Onboarding $onboarding
     *
     * @return Onboarding
     */public function verify(Onboarding $onboarding)
    {
        try {
            $onboarding->status = 'verify';
            return $onboarding->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Onboarding $onboarding
     *
     * @return Onboarding
     */public function approve(Onboarding $onboarding)
    {
        try {
            $onboarding->status = 'approve';
            return $onboarding->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Onboarding $onboarding
     *
     * @return Onboarding
     */public function publish(Onboarding $onboarding)
    {
        try {
            $onboarding->status = 'publish';
            return $onboarding->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Onboarding $onboarding
     *
     * @return Onboarding
     */
    public function archive(Onboarding $onboarding)
    {
        try {
            $onboarding->status = 'archive';
            return $onboarding->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Onboarding $onboarding
     *
     * @return Onboarding
     */
    public function unpublish(Onboarding $onboarding)
    {
        try {
            $onboarding->status = 'unpublish';
            return $onboarding->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
