<?php

namespace Bixo\Onboarding\Workflow;

use Bixo\Onboarding\Models\Onboarding;
use Validator;

class OnboardingValidator
{

    /**
     * Determine if the given onboarding is valid for complete status.
     *
     * @param Onboarding $onboarding
     *
     * @return bool / Validator
     */
    public function complete(Onboarding $onboarding)
    {
        return Validator::make($onboarding->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given onboarding is valid for verify status.
     *
     * @param Onboarding $onboarding
     *
     * @return bool / Validator
     */
    public function verify(Onboarding $onboarding)
    {
        return Validator::make($onboarding->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given onboarding is valid for approve status.
     *
     * @param Onboarding $onboarding
     *
     * @return bool / Validator
     */
    public function approve(Onboarding $onboarding)
    {
        return Validator::make($onboarding->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given onboarding is valid for publish status.
     *
     * @param Onboarding $onboarding
     *
     * @return bool / Validator
     */
    public function publish(Onboarding $onboarding)
    {
        return Validator::make($onboarding->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given onboarding is valid for archive status.
     *
     * @param Onboarding $onboarding
     *
     * @return bool / Validator
     */
    public function archive(Onboarding $onboarding)
    {
        return Validator::make($onboarding->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given onboarding is valid for unpublish status.
     *
     * @param Onboarding $onboarding
     *
     * @return bool / Validator
     */
    public function unpublish(Onboarding $onboarding)
    {
        return Validator::make($onboarding->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
